@@ -1,6 +1,7 @@
 from django.contrib import admin
 from django.contrib.auth.admin import UserAdmin
-from models import Profile
+
+from .models import Profile
 
 
 def deactivate(modeladmin, request, queryset):
